Quick Test Result

### Info

Connection Source

Source Tenant: {$ ctrl.quickResult.src_tenant_name $}

Source Segment: {$ ctrl.quickResult.src_segment_name $}

Source IP: {$ ctrl.quickResult.src_ip $}

Connection Destination

Destination IP: {$ ctrl.quickResult.dst_ip $}

### Results

Time Stamp

{$ ctrl.quickResult.test_time $}

Expected Result

{$ ctrl.quickResult.expected_result $}

Test Results

{$ ctrl.quickResult.test_result $}

Command Line Output

Hop-Index: {$ ctrl.quickResult.detail[0]['hop-index'] $}

Hop-Name: {$ ctrl.quickResult.detail[0]['hop-name'] $}

Path-Index: {$ ctrl.quickResult.detail[0]['path-index'] $}